%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Computation of QNMs for slowly rotating Kerr-de Sitter black holes
%  by means of a quantization condition
%  (c) Semyon Dyatlov, UC Berkeley, 2010 <dyatlov@berkeley.edu>
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% findr0.m - computes the value of r0 for the radial problem
% KDSD - a KDSData with omegaR and k filled in

function r0 = findr0(KDSD)

% Accuracy
eps = 1e-12;

% p1 = ((r^2 + a^2) Re(omega) - ak)^2
t1 = KDSD.a * KDSD.a * KDSD.omegaR - KDSD.a * KDSD.k;
p1 = [ t1 * t1 , 0 , 2 * KDSD.omegaR * t1, 0, KDSD.omegaR * KDSD.omegaR];

% p2 = DeltaR' * p1 - p1' * DeltaR, should be zero at r = r0
p2 = conv(KDSD.deltarc, jetdiff(p1, 1)) - conv(p1, jetdiff(KDSD.deltarc, 1));
r0 = newtonpoly(p2, 3 * KDSD.M, eps, 100);

end