%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Computation of QNMs for slowly rotating Kerr-de Sitter black holes
%  by means of a quantization condition
%  (c) Semyon Dyatlov, UC Berkeley, 2010 <dyatlov@berkeley.edu>
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% jetmul.m - multiply two jets
% X, Y - jets to be multiplied
% Z - the product of X and Y, truncated if necessary

function Z = jetmul(X, Y)

% Truncation code - common for several jet operations
dp = min(size(X, 2), size(Y, 2));
X = X(:, 1 : dp);
Y = Y(:, 1 : dp);

% Leibniz rule
Z = zeros(size(X));
for i = 1 : dp
    Z(:, i) = sum(X(:, 1 : i) .* Y(:, i : -1 : 1), 2);
end

end