%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Computation of QNMs for slowly rotating Kerr-de Sitter black holes
%  by means of a quantization condition
%  (c) Semyon Dyatlov, UC Berkeley, 2010 <dyatlov@berkeley.edu>
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% jetpoly.m - the jet of a polynomial
% c - the coefficient array for the polynomial; c(i) is the coefficient
%   next to x^(i - 1)
% depth - the depth of the jet we need to obtain
% grid - the grid

function X = jetpoly(c, depth, grid)

% Make sure the grid is vertical
if size(grid, 2) ~= 1
    grid = grid';
end

% Horner scheme - will replace if efficiency becomes a problem

X = zeros(length(grid), depth);
un = jetone(depth, grid);
id = jetid(depth, grid);
for i = numel(c) : -1 : 1
    if i < numel(c)
        X = jetmul(X, id);
    end
    X = jetsum(X, c(i) * un);
end

end