%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Computation of QNMs for slowly rotating Kerr-de Sitter black holes
%  by means of a quantization condition
%  (c) Semyon Dyatlov, UC Berkeley, 2010 <dyatlov@berkeley.edu>
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% loadQNM.m - load QNM data from a file
% prefix - prefix for the files
% k, l, m, a - quantization parameters, with a an array
% omega, lambda - resulting QNMs, each corresponding to its own value of a
% File format is the same as in outputQNM.m

function [omega, lambda] = loadQNM(prefix, k, l, m, a)
    fileName = [prefix, QNMsuffix(k, l, m)];

    disp(['Attempting to retrieve QNM information from ', fileName]);
    fid = fopen(fileName, 'r');
    if (fid == -1)
        error('File not found');
    end

    tData = textscan(fid, '%n%n%n%n%n');
    % Once again, a pretty inefficient piece of code
    for idx = 1 : numel(a)
        c = find(abs(tData{1} - a(idx)) < 1e-12);
        if (isempty(c))
            error('Not all values of a have been found');
        else
            omega(idx) = tData{2}(c(1)) + i * tData{3}(c(1));
            lambda(idx) = tData{4}(c(1)) + i * tData{5}(c(1));
        end
    end

    fclose(fid);
end