%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Computation of QNMs for slowly rotating Kerr-de Sitter black holes
%  by means of a quantization condition
%  (c) Semyon Dyatlov, UC Berkeley, 2010 <dyatlov@berkeley.edu>
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% newtonpoly.m - solve polynomial equations using Newton's method
% c - the coefficients of the polynomial; c(i) is the one next to x^(i - 1)
% x0 - the initial approximation
% eps - the sought accuracy: need |f(x)| < eps
% NMax - maximal number of steps before an error is invoked
% x - the answer
% Complex coefficients are allowed

function x = newtonpoly(c, x0, eps, NMax)

cnt = 0;
x = x0;
deg = length(c);

while 1
    % f(x)
    val = jetpoly(c, 1, x);
    
    if abs(val) < eps
        break;
    end
    if (cnt > NMax)
        error('Newton''s method did not converge');
    end
    cnt = cnt + 1;
    
    % f'(x)
    vald = jetpoly(c(2 : deg) .* (1 : deg - 1), 1, x);
    x = x - val / vald;
end

end