%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Computation of QNMs for slowly rotating Kerr-de Sitter black holes
%  by means of a quantization condition
%  (c) Semyon Dyatlov, UC Berkeley, 2010 <dyatlov@berkeley.edu>
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% outputQNM.m - output the computed QNMs for various values of a
% fileName - full path to the file where the QNMs will be recorded
% M, Lambda, a - parameters of the black hole. The variable a is an array
% m, l, k - quantization condition parameters
% N - order to which compute the symbols
% File format is:
% a real(omega) imag(omega) real(lambda) imag(lambda)

function outputQNM(fileName, M, Lambda, a, k, l, m, N)
    disp(['Outputting WKB QNMs to ', fileName]);

    [omega, lambda] = getQNM(M, Lambda, a, k, l, m, N);
    outf = fopen(fileName, 'wt');
    for i = 1 : length(a)
        fprintf(outf, '%.10e %.10e %.10e %.10e %.10e\n', ...
            a(i), real(omega(i)), imag(omega(i)), real(lambda(i)), imag(lambda(i)));
    end
    fclose(outf);
end